==> haskell-time-manager-0.0.1-74-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-time-manager.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 time-manager
version:              0.0.1
visibility:           public
id:                   time-manager-0.0.1-HUfU3chFeANEl67KYpShjm
key:                  time-manager-0.0.1-HUfU3chFeANEl67KYpShjm
license:              MIT
maintainer:           kazu@iij.ad.jp
author:               Michael Snoyman and Kazu Yamamoto
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             Scalable timer
description:          Scalable timer functions provided by a timer manager.
category:             System
abi:                  00ce320d34b559be9759399c3a63d643
exposed:              True
exposed-modules:      System.TimeManager
import-dirs:          /usr/lib/ghc-9.4.8/site-local/time-manager-0.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/time-manager-0.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/time-manager-0.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.4.8/time-manager-0.0.1
hs-libraries:         HStime-manager-0.0.1-HUfU3chFeANEl67KYpShjm
depends:
    auto-update-0.1.6-B3ftYI2ey2r5el4bZgPHbB base-4.17.2.1
    unliftio-0.2.25.1-4ouS4p8u42FHJEBnZmJiqL

haddock-interfaces:
    /usr/share/doc/haskell-time-manager/html/time-manager.haddock

haddock-html:         /usr/share/doc/haskell-time-manager/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-time-manager-0.0.1-75-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-time-manager.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 time-manager
version:              0.0.1
visibility:           public
id:                   time-manager-0.0.1-6wvqP4ScA4GJS6gCZ4Wv50
key:                  time-manager-0.0.1-6wvqP4ScA4GJS6gCZ4Wv50
license:              MIT
maintainer:           kazu@iij.ad.jp
author:               Michael Snoyman and Kazu Yamamoto
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             Scalable timer
description:          Scalable timer functions provided by a timer manager.
category:             System
abi:                  d8ec58c00af546a044be5cab6044fb5e
exposed:              True
exposed-modules:      System.TimeManager
import-dirs:          /usr/lib/ghc-9.4.8/site-local/time-manager-0.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/time-manager-0.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/time-manager-0.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.4.8/time-manager-0.0.1
hs-libraries:         HStime-manager-0.0.1-6wvqP4ScA4GJS6gCZ4Wv50
depends:
    auto-update-0.1.6-FWwEdBM4WUq2CmOnXBSdUp base-4.17.2.1
    unliftio-0.2.25.1-4ouS4p8u42FHJEBnZmJiqL

haddock-interfaces:
    /usr/share/doc/haskell-time-manager/html/time-manager.haddock

haddock-html:         /usr/share/doc/haskell-time-manager/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
